@@ -13,12 +13,220 @@
 # You should have received a copy of the GNU General Public License
 # along with this program; if not, write to the Free Software
 # Foundation, Inc., 59 Temple Place - Suite 330, Boston, MA  02111-1307, USA.
-
 """Expose package-wide elements."""
 
 from __future__ import annotations
 
-__version__ = "3.9.0"
+# Import all click's module-level content to allow for drop-in replacement.
+# XXX Star import is really badly supported by mypy for now and leads to lots of
+# "Module 'XXX' has no attribute 'YYY'". See: https://github.com/python/mypy/issues/4930
+from click import *  # noqa: F403
+from click._utils import UNSET
+from click.core import ParameterSource
+
+# Overrides click helpers with cloup's.
+from cloup import *  # type: ignore[no-redef, assignment] # noqa: F403
+
+# XXX Import types first to avoid circular imports. The True condition is a hack to
+# prevent ruff from re-ordering imports.
+if True:
+    from .types import ChoiceSource, EnumChoice
+
+from .colorize import (
+    ColorOption,
+    HelpExtraFormatter,
+    HelpExtraTheme,
+)
+from .commands import (
+    ExtraCommand,
+    ExtraContext,
+    ExtraGroup,
+    LazyGroup,
+)
+from .config import ConfigFormat, ConfigOption, NoConfigOption
+from .decorators import (  # type: ignore[no-redef]
+    argument,
+    color_option,
+    command,
+    config_option,
+    group,
+    help_option,
+    lazy_group,
+    no_config_option,
+    option,
+    show_params_option,
+    table_format_option,
+    telemetry_option,
+    timer_option,
+    verbose_option,
+    verbosity_option,
+    version_option,
+)
+from .logging import (
+    ExtraFormatter,
+    ExtraStreamHandler,
+    LogLevel,
+    VerboseOption,
+    VerbosityOption,
+    extraBasicConfig,
+    new_extra_logger,
+)
+from .parameters import (
+    Argument,
+    ExtraOption,
+    Option,
+    ParamStructure,
+    ShowParamsOption,
+    search_params,
+)
+from .table import (
+    TableFormat,
+    TableFormatOption,
+    print_table,
+    render_table,
+)
+from .telemetry import TelemetryOption
+from .testing import ExtraCliRunner
+from .timer import TimerOption
+from .version import ExtraVersionOption
+
+__all__ = [  # noqa: F405
+    "Abort",
+    "annotations",
+    "Argument",
+    "argument",
+    "BadArgumentUsage",
+    "BadOptionUsage",
+    "BadParameter",
+    "BOOL",
+    "Choice",
+    "ChoiceSource",
+    "clear",
+    "ClickException",
+    "Color",
+    "color_option",
+    "ColorOption",
+    "Command",
+    "command",
+    "CommandCollection",
+    "config_option",
+    "ConfigFormat",
+    "ConfigOption",
+    "confirm",
+    "confirmation_option",
+    "constrained_params",
+    "constraint",
+    "ConstraintMixin",
+    "Context",
+    "DateTime",
+    "dir_path",
+    "echo",
+    "echo_via_pager",
+    "edit",
+    "EnumChoice",
+    "extraBasicConfig",
+    "ExtraCliRunner",
+    "ExtraCommand",
+    "ExtraContext",
+    "ExtraFormatter",
+    "ExtraGroup",
+    "ExtraOption",
+    "ExtraStreamHandler",
+    "ExtraVersionOption",
+    "File",
+    "file_path",
+    "FileError",
+    "FLOAT",
+    "FloatRange",
+    "format_filename",
+    "get_app_dir",
+    "get_binary_stream",
+    "get_current_context",
+    "get_text_stream",
+    "getchar",
+    "Group",
+    "group",
+    "help_option",
+    "HelpExtraFormatter",
+    "HelpExtraTheme",
+    "HelpFormatter",
+    "HelpSection",
+    "HelpTheme",
+    "INT",
+    "IntRange",
+    "launch",
+    "lazy_group",
+    "LazyGroup",
+    "LogLevel",
+    "make_pass_decorator",
+    "MissingParameter",
+    "new_extra_logger",
+    "no_config_option",
+    "NoConfigOption",
+    "NoSuchOption",
+    "open_file",
+    "Option",
+    "option",
+    "option_group",
+    "OptionGroup",
+    "OptionGroupMixin",
+    "Parameter",
+    "ParameterSource",
+    "ParamStructure",
+    "ParamType",
+    "pass_context",
+    "pass_obj",
+    "password_option",
+    "Path",
+    "path",
+    "pause",
+    "print_table",
+    "progressbar",
+    "prompt",
+    "render_table",
+    "search_params",
+    "secho",
+    "Section",
+    "SectionMixin",
+    "show_params_option",
+    "ShowParamsOption",
+    "STRING",
+    "Style",
+    "style",
+    "table_format_option",
+    "TableFormat",
+    "TableFormatOption",
+    "telemetry_option",
+    "TelemetryOption",
+    "timer_option",
+    "TimerOption",
+    "Tuple",
+    "UNPROCESSED",
+    "UNSET",
+    "unstyle",
+    "UsageError",
+    "UUID",
+    "verbose_option",
+    "VerboseOption",
+    "verbosity_option",
+    "VerbosityOption",
+    "version_option",
+    "VersionOption",
+    "warnings",
+    "wrap_text",
+]
+"""Expose all of Click, Cloup and Click Extra.
+
+.. note::
+    The content of ``__all__`` is checked and enforced in unittests.
+
+.. todo::
+    Test ruff __all__ formatting capabilities. And if good enough, remove ``__all__``
+    checks in unittests.
+"""
+
+
+__version__ = "7.0.0"
 """Examples of valid version strings according :pep:`440#version-scheme`:
 
 .. code-block:: python
@@ -30,132 +238,3 @@ __version__ = "3.9.0"
     __version__ = "1.2.3"  # Final Release
     __version__ = "1.2.3.post1"  # Post Release 1
 """
-
-# Import all click's module-level content to allow for drop-in replacement.
-# XXX Star import is really badly supported by mypy for now and leads to lots of
-# "Module 'XXX' has no attribute 'YYY'". See: https://github.com/python/mypy/issues/4930
-from click import *  # noqa: E402, F403
-from click.core import ParameterSource  # noqa: E402
-
-# Overrides some of click helpers with cloup's.
-from cloup import (  # noqa: E402
-    Argument,
-    Command,
-    Group,
-    HelpFormatter,
-    HelpTheme,
-    Option,
-    Style,
-    argument,
-    option,
-    option_group,
-)
-
-from .colorize import ColorOption, HelpOption  # noqa: I001, E402
-from .commands import TimerOption  # noqa: I001, E402
-from .config import ConfigOption, ShowParamsOption  # noqa: I001, E402
-from .decorators import (  # type: ignore # noqa: I001, E402
-    color_option,
-    command,  # noqa: E402
-    config_option,
-    extra_command,
-    extra_group,
-    group,  # noqa: E402
-    help_option,
-    show_params_option,
-    table_format_option,
-    timer_option,
-    verbosity_option,
-    version_option,
-)
-from .logging import VerbosityOption  # noqa: I001, E402
-from .parameters import ExtraOption  # noqa: I001, E402
-from .version import VersionOption  # noqa: I001, E402
-
-__all__ = [  # noqa: F405
-    "Abort",
-    "Argument",
-    "argument",
-    "BadArgumentUsage",
-    "BadOptionUsage",
-    "BadParameter",
-    "BaseCommand",
-    "BOOL",
-    "Choice",
-    "clear",
-    "ClickException",
-    "color_option",
-    "ColorOption",
-    "command",
-    "Command",
-    "CommandCollection",
-    "config_option",
-    "ConfigOption",
-    "confirm",
-    "confirmation_option",
-    "Context",
-    "DateTime",
-    "echo",
-    "echo_via_pager",
-    "edit",
-    "extra_command",
-    "extra_group",
-    "ExtraOption",
-    "File",
-    "FileError",
-    "FLOAT",
-    "FloatRange",
-    "format_filename",
-    "get_app_dir",
-    "get_binary_stream",
-    "get_current_context",
-    "get_text_stream",
-    "getchar",
-    "group",
-    "Group",
-    "help_option",
-    "HelpFormatter",
-    "HelpOption",
-    "HelpTheme",
-    "INT",
-    "IntRange",
-    "launch",
-    "make_pass_decorator",
-    "MissingParameter",
-    "MultiCommand",
-    "NoSuchOption",
-    "open_file",
-    "option",
-    "Option",
-    "option_group",
-    "OptionParser",
-    "Parameter",
-    "ParameterSource",
-    "ParamType",
-    "pass_context",
-    "pass_obj",
-    "password_option",
-    "Path",
-    "pause",
-    "progressbar",
-    "prompt",
-    "secho",
-    "show_params_option",
-    "ShowParamsOption",
-    "STRING",
-    "style",
-    "Style",
-    "table_format_option",
-    "timer_option",
-    "TimerOption",
-    "Tuple",
-    "UNPROCESSED",
-    "unstyle",
-    "UsageError",
-    "UUID",
-    "verbosity_option",
-    "VerbosityOption",
-    "version_option",
-    "VersionOption",
-    "wrap_text",
-]
